@@ -142,6 +142,7 @@ echo '<!doctype html><HTML>
 <head>
 <TITLE> NOALYSS </TITLE>
 <link rel="shortcut icon" type="image/ico" href="favicon.ico" />
+<meta name="viewport" content="width=device-width, initial-scale=1.0">
 <style>
 BODY {
 background-color:white;
@@ -200,6 +201,34 @@ border-style:  solid;
 border-width:  0px;
 background-image: url("image/bg-submit3.gif");
 background-repeat: repeat-x repeat-y;
+}
+@media only screen and (max-width : 900px) {
+    #alternate_browser {
+        display : none;
+    }
+   #logo_id {
+    width:336px;
+    height:160px;
+    }
+    .input_text {
+        width:8em;
+    }
+}
+@media only screen and (min-width : 901px) {
+    #alternate_browser {
+        position:absolute;
+        bottom: 0px;
+        left:0px;
+        z-index: -1
+    }
+    #logo_id {
+    width:420px;
+    height:200px;
+    }
+    .input_text {
+        width: 24em;
+    }
+
 }
 </style>
 <script src="js/scripts.js" type="text/javascript"></script>
@@ -232,7 +261,7 @@ if (isset ($_REQUEST['reconnect']) && isset ($_REQUEST['backurl'])) {
 }
 echo '
 <span style="background-color:#879ed4;color:white;padding-left:4px;padding-right:4px;">
-version  6912 - '.$my_domain.'
+version  6913 - '.$my_domain.'
 </span>
 <BR>
 <BR>
@@ -240,7 +269,7 @@ version  6912 - '.$my_domain.'
 
 <BR>
 <center>
-<IMG SRC="image/logo6820.png" style="width:420px;height:200px" alt="NOALYSS">
+<IMG SRC="image/logo6820.png" id="logo_id" alt="NOALYSS">
 <BR>
 <BR>
 <BR>
@@ -251,11 +280,11 @@ version  6912 - '.$my_domain.'
 <TABLE  BORDER=0 CELLSPACING=0>
 <TR>
 <TD class="cell">Utilisateur</TD>
-<TD><input type="text" class="input_text" value="" id="p_user" name="p_user" tabindex="1"></TD>
+<TD><input type="text" class="input_text" value="" id="p_user" name="p_user" autofocus tabindex="1"></TD>
 </TR>
 <TR>
 <TD class="cell"> Mot de passe </TD>
-<TD><INPUT TYPE="PASSWORD"  class="input_text" value=""  NAME="p_pass" tabindex="2"></TD>
+<TD><INPUT TYPE="PASSWORD"  class="input_text" value=""  NAME="p_pass"  tabindex="2"></TD>
 </TR>';
 
 
@@ -323,7 +352,7 @@ echo '
     </script>
 <?php endif; ?>
         
-<div style="position:absolute;bottom: 0px;left:0px;z-index: -1">
+<div  id="alternate_browser">
     <p>Nous conseillons d'utiliser Firefox ou chrome.</p>
     <p>We recommend to use Firefox or Chrome.</p>
 <ul style="list-style:none;display:block">
