@@ -134,16 +134,8 @@ if ( $User->admin == 0 || (defined("MULTI")&& MULTI == 0 ) )
     if ( $folder != null  && count($folder) == 1 )
     {
 
-        if ( $User->check_dossier($folder[0]['dos_id']) == 'P')
-        {
-            redirect('extension.php?gDossier='.$folder[0]['dos_id']);
-            exit();
-        }
-        else
-        {
             redirect('do.php?gDossier='.$folder[0]['dos_id']);
             exit();
-        }
     }
 
 }
@@ -166,12 +158,12 @@ echo '<div id="module">'.$result.'</div>';
 echo '</div>';
 ?>
 <div class="foldercontent">
-	<span style="display:block;margin:2%">
+	<span style="margin:2%" class="visible_gt800">
  <?php
                         echo _('Cherche').HtmlInput::infobulle(23);
 ?>
 <?php
-	echo HtmlInput::filter_table("folder", '1,2',1);
+	echo HtmlInput::filter_table("folder", '0,1,2',1);
 ?>
 </span>
 <?php
