@@ -3,7 +3,7 @@
 //see licence.txt
 
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once NOALYSS_INCLUDE.'/class_anc_acc_list.php';
+require_once NOALYSS_INCLUDE.'/class/class_anc_acc_list.php';
 echo '<div class="content">';
 $tab = new Anc_Acc_List($cn);
 $tab->get_request();
