@@ -24,11 +24,11 @@ if ( !defined ('ALLOWED') )  die('Appel direct ne sont pas permis');
  * @brief Manage the tags
  *
  */
-require_once NOALYSS_INCLUDE.'/class_tag.php';
-require_once NOALYSS_INCLUDE.'/class_tool_uos.php';
+require_once NOALYSS_INCLUDE.'/class/class_tag.php';
+require_once NOALYSS_INCLUDE.'/lib/class_single_record.php';
 
 $tag=new Tag($cn);
-$uos=new Tool_Uos('tag');
+$uos=new Single_Record('tag');
 if ( isset ($_POST['save_tag_sb']))
 {
     if ( ! isset ($_POST['remove']))
