@@ -74,7 +74,8 @@ if ($low_action == "list")
 		<?php
 		echo dossier::hidden();
 		$a = (isset($_GET['query'])) ? $_GET['query'] : "";
-		printf(_('Cherche') . HtmlInput::filter_table("contact_tb", "0,1,2,3,4,5,6", 1));
+                echo _("Cherche ").HtmlInput::filter_table_form("contact_tb", '0,1,2,3,4,5,6', 1,"query",$a);
+
 		$sel_card = new ISelect('cat');
 		$sel_card->value = $cn->make_array('select fd_id, fd_label from fiche_def ' .
 			' where  frd_id=' . FICHE_TYPE_CONTACT .
