@@ -24,11 +24,8 @@
  *
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-header('Pragma: public');
-header('Content-type: application/csv');
-header('Content-Disposition: attachment;filename="jrn.csv"',FALSE);
-
 require_once  NOALYSS_INCLUDE.'/class/class_anc_listing.php';
+require_once  NOALYSS_INCLUDE.'/lib/class_noalyss_csv.php';
 
 $cn=Dossier::connect();
 
