@@ -23,8 +23,8 @@
  * \brief show the lettering by account
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once  NOALYSS_INCLUDE.'/class_ipopup.php';
-require_once NOALYSS_INCLUDE.'/class_lettering.php';
+require_once  NOALYSS_INCLUDE.'/lib/class_ipopup.php';
+require_once NOALYSS_INCLUDE.'/class/class_lettering.php';
 
 
 echo '<div class="content">';
