@@ -106,7 +106,8 @@ function j($p_string)
  */
 function nb($p_number)
 {
-    $r = sprintf('%.2f', $p_number);
+    $r=trim($p_number);
+    $r = sprintf('%.4f', $p_number);
     $r = str_replace('.', ',', $r);
 
     return $r;
@@ -670,6 +671,12 @@ function set_language()
     // desactivate local check
     if ( defined("LOCALE") && LOCALE==0 ) return;
     if ( ! isset ($_SESSION['g_lang'])) return;
+    
+    /*
+     * If translation is not supported by current
+     */
+    if (! function_exists("bindtextdomain")) return;
+    
     $dir = "";
     // set differently the language depending of the operating system
     if (what_os() == 1)
