@@ -22,8 +22,8 @@
  *  action contains the sub action 
  */
 if ( ! defined ('ALLOWED') ) die('Appel direct ne sont pas permis');
-require_once NOALYSS_INCLUDE.'/class_ihidden.php';
-require_once NOALYSS_INCLUDE.'/class_acc_parm_code.php';
+require_once NOALYSS_INCLUDE.'/lib/class_ihidden.php';
+require_once NOALYSS_INCLUDE.'/class/class_acc_parm_code.php';
 echo '<div class="content">';
 
 $gDossier=dossier::id();
@@ -64,7 +64,7 @@ echo "</div>";
 if ( isset ($_POST['mod'] ))
 {
     echo '<div style="float:left;">';
-    echo IPoste::ipopup('ipop_account');
+    
     echo '<fieldset>';
     echo "<legend>Voulez-vous vraiment modifier ?</legend>";
     echo '<FORM METHOD="POST">';
