@@ -20,7 +20,7 @@
 // Copyright Author Dany De Bontridder danydb@aevalys.eu
 if (!defined('ALLOWED'))
     die('Appel direct ne sont pas permis');
-require_once NOALYSS_INCLUDE.'/class_profile_sql.php';
+require_once NOALYSS_INCLUDE.'/database/class_profile_sql.php';
 global $cn;
 
 //**********************************************
@@ -57,7 +57,8 @@ if (isset($_POST['change_profile']))
     }
     catch (Exception $exc)
     {
-        echo $exc->getTraceAsString();
+        echo $exc->getMessage();
+        error_log( $exc->getTraceAsString());
         throw $exc;
     }
 }
@@ -95,7 +96,8 @@ if (isset($_POST['change_stock']))
     }
     catch (Exception $exc)
     {
-        echo $exc->getTraceAsString();
+        echo $exc->getMessage();
+        error_log($exc->getTraceAsString());
         throw $exc;
     }
 }
@@ -143,7 +145,10 @@ if (isset($_POST['save_name']))
 //************************************
 if (isset($_POST['clone']))
 {
-    extract($_POST);
+    $p_id = HtmlInput::default_value_post("p_id", 0);
+    if ( $p_id == 0 || isNumber($p_id) == 0) {
+     throw new Exception (_('Argument'));
+    }
     try
     {
         $cn->start();
@@ -152,18 +157,30 @@ if (isset($_POST['clone']))
 			select 'copie de '||p_name,p_desc,with_calc,
 			with_direct_form from profile where p_id=$1 returning p_id", array($p_id));
         $cn->exec_sql("
-				insert into profile_menu (p_id,me_code,me_code_dep,p_order,p_type_display,pm_default)
-				select $1,me_code,me_code_dep,p_order,p_type_display,pm_default from profile_menu
-				where p_id=$2
+                        insert into profile_menu (p_id,me_code,me_code_dep,p_order,p_type_display,pm_default)
+                        select $1,me_code,me_code_dep,p_order,p_type_display,pm_default from profile_menu
+                        where p_id=$2
 			", array($new_id, $p_id));
+        $cn->exec_sql("select menu_complete_dependency($1)",array($new_id));
+        $cn->exec_sql("update profile_menu 
+            set pm_id_dep=(select distinct higher_dep 
+                            from v_menu_dependency as a 
+                            where
+                            a.pm_id= profile_menu.pm_id) 
+                        where pm_id_dep is null and p_id=$1",array($new_id));
         $cn->commit();
         $p_id=$new_id;
+        $_POST['p_id'] = $new_id;
+        $_GET['p_id'] = $new_id;
+        $_REQUEST['p_id'] = $new_id;
+        $_POST['tab']="profile_gen_div";
     }
     catch (Exception $exc)
     {
         echo alert($exc->getMessage());
         $cn->rollback();
     }
+
 }
 //************************************
 // Delete
@@ -189,7 +206,7 @@ if (isset($_POST['delete_profil']))
     }
 }
 //************************************
-// Modify the menu or delete it
+// Modify the menu 
 //************************************
 if (isset($_POST['mod']))
 {
@@ -328,7 +345,15 @@ if (isset($_POST['add_menu'])||isset($_POST['add_impress']))
          * if me_code_dep == -1, it means it is null
          */
         $me_code_dep=($me_code_dep==-1)?null:$me_code_dep;
-
+        
+        /*
+         * Do not insert twice the same menu 
+         */
+        $duplicate = $cn->get_value(" select count(*) from profile_menu where "
+                . " pm_id_dep = $1 and me_code = $2",array($p_dep,$me_code));
+        if ( $duplicate > 0 ) {
+            throw new Exception(_('Doublon'));
+        }
         $pm_default=(isset($pm_default))?1:0;
         $cn->exec_sql("
                         insert into profile_menu (me_code,me_code_dep,p_id,p_order,pm_default,p_type_display,pm_id_dep)
@@ -400,7 +425,7 @@ echo '</div>';
 echo '<div id="detail_profile" class="content">';
 if (isset($_POST['p_id']))
 {
-    require_once NOALYSS_INCLUDE.'/ajax_get_profile.php';
+    require_once NOALYSS_INCLUDE.'/ajax/ajax_get_profile.php';
     ?>
     <script>
         $('list_profile').hide()
@@ -419,4 +444,17 @@ if (isset($_POST['delete_profil']))
     <?php
 
 }
+$dep=HtmlInput::default_value_post("dep", 0);
 ?>
+<script>
+    var selected_menu="<?php echo $dep;?>";
+    function menu_select(rowid) {
+        $('sub'+rowid).addClassName("selectedmenu");
+        if ( selected_menu != "0" && rowid != selected_menu ) {
+            if ( $('sub'+selected_menu) ) {
+                $('sub'+selected_menu).removeClassName("selectedmenu");
+            }
+        }
+        selected_menu=rowid;
+    }
+</script>  
\ No newline at end of file
