@@ -200,10 +200,12 @@ endif;
 	for($i=0;$i<count($late_operation);$i++):
 	?>
 	<li>
-		<?php echo HtmlInput::detail_action($late_operation[$i]['ag_id'],h($late_operation[$i]['ag_ref']))?>
 	<span>
-	<?php echo smaller_date($late_operation[$i]['ag_timestamp_fmt'])?>
+	<?php echo smaller_date($late_operation[$i]['ag_timestamp_fmt']) , " ",
+                hb($late_operation[$i]['ag_hour']);
+                ?>
 	</span>
+		<?php echo HtmlInput::detail_action($late_operation[$i]['ag_id'],h($late_operation[$i]['ag_ref']))?>
 		<span  style="font-weight: bolder ">
 			<?php echo h($late_operation[$i]['vw_name'])?>
 		</span>
@@ -219,6 +221,9 @@ endif;
 	<?php else : ?>
 	<h2 class='notice'><?php echo _("Aucune action en retard")?></h2>
 	<?php endif; ?>
+         <p style="text-align: center">
+        <?php echo HtmlInput::button_hide("action_late_div")?>
+        </p>
 	</div>
 
 	<div id="action_now_div" class="inner_box" style="display:none;margin-left:25%;width: 50%;top:25%;min-height:50%;overflow: auto;">
@@ -231,10 +236,11 @@ endif;
 	for($i=0;$i<count($last_operation);$i++):
 	?>
 	<li>
-		<?php echo HtmlInput::detail_action($last_operation[$i]['ag_id'],h($last_operation[$i]['ag_ref']))?>
 	<span>
-	<?php echo smaller_date($last_operation[$i]['ag_timestamp_fmt'])?>
+	<?php echo smaller_date($last_operation[$i]['ag_timestamp_fmt'])," ",
+                $last_operation[$i]['ag_hour']?>
 	</span>
+		<?php echo HtmlInput::detail_action($last_operation[$i]['ag_id'],h($last_operation[$i]['ag_ref']))?>
 		<span  style="font-weight: bolder ">
 			<?php echo h($last_operation[$i]['vw_name'])?>
 		</span>
@@ -247,6 +253,9 @@ endif;
 	</li>
 	<?php endfor;?>
 	</ol>
+        <p style="text-align: center">
+        <?php echo HtmlInput::button_hide("action_now_div")?>
+        </p>
 <?php endif; ?>
 	</div>
 	<?php display_dashboard_operation($supplier_now,_("Fournisseurs à payer aujourd'hui"),'supplier_now_div'); ?>
@@ -293,7 +302,7 @@ for($i=0;$i<count($last_ledger);$i++):
      echo HtmlInput::title_box(_('Suivi'),"last_operation_management_div",'zoom','onclick="action_show('.dossier::id().')"');
     ?>
     <?php
-    require_once NOALYSS_INCLUDE.'/class_follow_up.php';
+    require_once NOALYSS_INCLUDE.'/class/class_follow_up.php';
     $gestion=new Follow_Up($cn);
     $array=$gestion->get_last(MAX_ACTION_SHOW);
     $len_array=count($array);
