@@ -11,6 +11,7 @@
              'jr_id'=>$obj->det->jr_id,
              'act'=>'de',
              'div'=>$div,
+             'op'=>'ledger',
             'ajax'=>$callback));
      $msg_close=_('Fermer');
      $msg_pop=_('Ouvrir dans une fenêtre séparée');
@@ -26,5 +27,5 @@
 </div>
 <?php echo _("Opération ID")."=".hb($obj->det->jr_internal); ?>
 <div id="<?php echo $div.'info'?>" class="divinfo"></div>
-<?php require_once NOALYSS_INCLUDE.'/class_itextarea.php';
+<?php require_once NOALYSS_INCLUDE.'/lib/class_itextarea.php';
 ?>
\ No newline at end of file
